@@ -5,6 +5,7 @@ from .helpers import shell_run
 from .helpers import print_error
 from .helpers import print_ok
 from .helpers import print_empty
+from .helpers import run_unit_tests
 import datetime
 from .constants import CONFIG_FILE_NAME_FLAKE8, CONFIG_FILE_CONTENT_FLAKE8
 from .constants import CONFIG_FILE_NAME_RADON, CONFIG_FILE_CONTENT_RADON
@@ -52,24 +53,24 @@ def run_qa(directory, verbose=False):
 
     # Unit tests
     print_default('Django unit tests')
-    cmd = f'python3 {directory}/manage.py test --keepdb'
-    lines = shell_run(cmd)
-    if 'OK' in lines:
-        print_ok(lines, verbose)
-    else:
-        print_error(lines)
+    tests_result = run_unit_tests(())
+
+    if tests_result['failures']:
+        print_error(tests_result['output'])
         error_count += 1
+    else:
+        print_ok('', verbose)
 
     # Unit tests garpix_page
     if 'garpix_page' in settings.INSTALLED_APPS:
         print_default('Django unit tests garpix_page')
-        cmd = f'python3 {directory}/manage.py test garpix_page --keepdb'
-        lines = shell_run(cmd)
-        if 'OK' in lines:
-            print_ok(lines, verbose)
-        else:
-            print_error(lines)
+        garpix_tests_result = run_unit_tests(('garpix_page', ))
+
+        if garpix_tests_result['failures']:
+            print_error(garpix_tests_result['output'])
             error_count += 1
+        else:
+            print_ok('', verbose)
 
     # Cyclomatic complexity
     print_default(f'Cyclomatic complexity with radon (see "{CONFIG_FILE_NAME_RADON}")')
